| Title: | Vignettes for Analyzing Data using 'OlinkAnalyze' |
|---|---|
| Description: | Exemplifying analysis of large-scale protein data from the 'Olink platform', primarily relative protein expression data that has been exported from 'Olink NPX Software', as well as QUANT data from 'Olink'. QUANT data is log-transformed. Materials focus on reading data, demonstrating data wrangling and quality control analysis, performing statistical analysis and generating figures to visualize the results of the statistical analysis. The goal of this package is to guide users extract biological insights from large-scale protein data run on the 'Olink platform'. More information on 'Olink' data can be found at <https://olink.com/>. |
| Authors: | Kathleen Nevola [aut, cre] (ORCID: <https://orcid.org/0000-0002-5183-6444>, kathy-nevola), Marianne Sandin [aut] (ORCID: <https://orcid.org/0000-0001-6186-963X>, marisand), Jamey Guess [aut] (ORCID: <https://orcid.org/0000-0002-4017-0923>, jrguess), Simon Forsberg [aut] (ORCID: <https://orcid.org/0000-0002-7451-9222>, simfor), Christoffer Cambronero [aut] (Orbmac), Pascal Pucholt [aut] (ORCID: <https://orcid.org/0000-0003-3342-1373>, AskPascal), Boxi Zhang [aut] (ORCID: <https://orcid.org/0000-0001-7758-6204>, boxizhang), Masoumeh Sheikhi [aut] (MasoumehSheikhi), Klev Diamanti [aut] (ORCID: <https://orcid.org/0000-0002-4922-8415>, klevdiamanti), Amrita Kar [aut] (amrita-kar), Lei Conze [aut] (leiliuC), Kristyn Chin [aut] (kristynchin-olink), Danai Topouza [aut] (dtopouza, ORCID: <https://orcid.org/0000-0002-6897-9281>), Stephen Pollo [aut] (spollo-olprot, ORCID: <https://orcid.org/0000-0001-9252-4976>), Kang Dong [aut] (KangD-dev, ORCID: <https://orcid.org/0000-0002-4567-5007>), Kristian Hodén [ctb] (ORCID: <https://orcid.org/0000-0003-0354-0662>, kristianHoden), Per Eriksson [ctb] (ORCID: <https://orcid.org/0000-0001-7633-403X>, b_watcher), Nicola Moloney [ctb] (ORCID: <https://orcid.org/0000-0003-4967-3284>), Britta Lötstedt [ctb] (ORCID: <https://orcid.org/0000-0003-3545-5489>), Emmett Sprecher [ctb] (ORCID: <https://orcid.org/0000-0002-7710-695X>), Jessica Barbagallo [ctb] (jbarbagallo), Olof Mansson [ctr] (olofmansson), Ola Caster [ctb] (OlaCaster), Olink [cph, fnd] |
| Maintainer: | Kathleen Nevola <[email protected]> |
| License: | AGPL (>= 3) |
| Version: | 1.0.1 |
| Built: | 2026-06-08 20:17:03 UTC |
| Source: | https://github.com/cran/OlinkAnalyzeVignettes |
Open the Olink Analyze GitHub repo page
open_docs()open_docs()
None opens Olink Analyze repo page in browser