| Type: | Package |
| Title: | Vignettes for Analyzing Data using 'OlinkAnalyze' |
| Version: | 1.0.1 |
| Description: | Exemplifying analysis of large-scale protein data from the 'Olink platform', primarily relative protein expression data that has been exported from 'Olink NPX Software', as well as QUANT data from 'Olink'. QUANT data is log-transformed. Materials focus on reading data, demonstrating data wrangling and quality control analysis, performing statistical analysis and generating figures to visualize the results of the statistical analysis. The goal of this package is to guide users extract biological insights from large-scale protein data run on the 'Olink platform'. More information on 'Olink' data can be found at https://olink.com/. |
| Contact: | biostattools@olink.com |
| URL: | https://olink.com/ https://github.com/Olink-Proteomics/OlinkRPackage |
| License: | AGPL (≥ 3) |
| Encoding: | UTF-8 |
| Depends: | R (≥ 4.1.0) |
| Suggests: | dplyr (≥ 1.2.0), ggplot2, ggpubr, ggrepel, kableExtra, knitr, OlinkAnalyze, stringr, tidyr |
| VignetteBuilder: | knitr |
| Config/roxygen2/version: | 8.0.0 |
| NeedsCompilation: | no |
| Packaged: | 2026-06-01 18:27:06 UTC; kathy.nevola |
| Author: | Kathleen Nevola |
| Maintainer: | Kathleen Nevola <biostattools@olink.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-06-08 14:50:26 UTC |
OlinkAnalyzeVignettes: Vignettes for Analyzing Data using 'OlinkAnalyze'
Description
Exemplifying analysis of large-scale protein data from the 'Olink platform', primarily relative protein expression data that has been exported from 'Olink NPX Software', as well as QUANT data from 'Olink'. QUANT data is log-transformed. Materials focus on reading data, demonstrating data wrangling and quality control analysis, performing statistical analysis and generating figures to visualize the results of the statistical analysis. The goal of this package is to guide users extract biological insights from large-scale protein data run on the 'Olink platform'. More information on 'Olink' data can be found at https://olink.com/.
Author(s)
Maintainer: Kathleen Nevola biostattools@olink.com (ORCID) (kathy-nevola)
Authors:
Kathleen Nevola biostattools@olink.com (ORCID) (kathy-nevola)
Marianne Sandin (ORCID) (marisand)
Jamey Guess (ORCID) (jrguess)
Simon Forsberg (ORCID) (simfor)
Christoffer Cambronero (Orbmac)
Pascal Pucholt (ORCID) (AskPascal)
Boxi Zhang (ORCID) (boxizhang)
Masoumeh Sheikhi (MasoumehSheikhi)
Klev Diamanti (ORCID) (klevdiamanti)
Amrita Kar (amrita-kar)
Lei Conze (leiliuC)
Kristyn Chin (kristynchin-olink)
Danai Topouza (ORCID) (dtopouza)
Stephen Pollo (ORCID) (spollo-olprot)
Kang Dong (ORCID) (KangD-dev)
Other contributors:
Kristian Hodén (ORCID) (kristianHoden) [contributor]
Per Eriksson (ORCID) (b_watcher) [contributor]
Nicola Moloney (ORCID) [contributor]
Britta Lötstedt (ORCID) [contributor]
Emmett Sprecher (ORCID) [contributor]
Jessica Barbagallo (jbarbagallo) [contributor]
Olof Mansson (olofmansson) [contractor]
Ola Caster (OlaCaster) [contributor]
Olink [copyright holder, funder]
See Also
Useful links:
Open the Olink Analyze GitHub repo page
Description
Open the Olink Analyze GitHub repo page
Usage
open_docs()
Value
None opens Olink Analyze repo page in browser